<?php
# $Id: dumper.php,v 1.11 2016/04/29 13:00:32 rp Exp $
#

/* This is where input files live. Adjust as necessary. */
$searchpath = "../data ../../data";
$infile = "PLOP-datasheet.pdf";

try{
    # create a new PLOP object
    $plop = new PLOP();

    $docoptlist = "requiredmode=minimum";
    $globaloptlist = "";

    $plop->set_option($globaloptlist);

    $optlist = sprintf("searchpath={%s}", $searchpath);
    $plop->set_option($optlist);

    if (($doc = $plop->open_document($infile, $docoptlist)) == 0)
    {
	die("ERROR: " .  $plop->get_errmsg() .  "\n");
    }

    # --------- general information (always available)

    $pcosmode = $plop->pcos_get_number($doc, "pcosmode");

    print("<pre>\n");
    printf("       File name: %s\n", $plop->pcos_get_string($doc, "filename"));

    printf("     PDF version: %s\n",
	$plop->pcos_get_string($doc, "pdfversionstring"));

    printf("      Encryption: %s\n",
	$plop->pcos_get_string($doc, "encrypt/description"));

    $recipientcount =
	    (int) $plop->pcos_get_number( $doc, "length:encrypt/recipients");

    if ($recipientcount > 0)
    {
	printf("Recipient groups: %d\n", $recipientcount);
	printf("      Digital ID: ");

	if ($pcosmode == 2)
	    printf("supplied digital ID has master permissions\n");
	else if ($pcosmode == 1)
	    printf("supplied digital ID doesn't have master permissions\n");
	else
	    printf("no suitable digital ID supplied\n");
    }

    printf("       Master pw: %s\n",
	$plop->pcos_get_number($doc, "encrypt/master") ? "yes" : "no");

    printf("         User pw: %s\n",
	$plop->pcos_get_number($doc, "encrypt/user") ? "yes" : "no");

    printf("    Text copying: %s\n",
	$plop->pcos_get_number($doc, "encrypt/nocopy") ? "no" : "yes");

    printf("      Linearized: %s\n",
	$plop->pcos_get_number($doc, "linearized") ? "yes" : "no");

    if ($pcosmode == 0) {
	die("    Minimum mode: no more information available\n\n");
    }

    # --------- more details (requires at least user password)

    printf("    PDF/X status: %s\n", $plop->pcos_get_string($doc, "pdfx"));

    printf("    PDF/A status: %s\n", $plop->pcos_get_string($doc, "pdfa"));
    printf("   PDF/UA status: %s\n", $plop->pcos_get_string($doc, "pdfua"));
    printf("   PDF/VT status: %s\n", $plop->pcos_get_string($doc, "pdfvt"));

    printf("        XFA data: %s\n",
        $plop->pcos_get_string($doc, "type:/Root/AcroForm/XFA") != "null"
                                    ? "yes" : "no");

    printf("      Tagged PDF: %s\n\n",
	$plop->pcos_get_number($doc, "tagged") ? "yes" : "no");

    # --------- analyze digital signatures 

    $count = $plop->pcos_get_number($doc, "length:signaturefields");

    for ($i=0; $i < $count; $i++)
    {
        printf("   Sig. field #%d: '%s',", i+1,
            $plop->pcos_get_string($doc, "signaturefields[$i]/fullname"));

        printf(" %s", ($plop->pcos_get_number($doc,
            "signaturefields[$i]/visible") ? "visible" : "invisible"));

        $sigtype = $plop->pcos_get_string($doc, "signaturefields[$i]/sigtype");

        if ($sigtype == "none")
        {
            printf(", unsigned\n");
            continue;
        }

        printf(" $sigtype signature");

        if ($sigtype == "certification")
        {
            printf(" (%s allowed)", $plop->pcos_get_string($doc,
                    "signaturefields[$i]/permissions"));
        }

        if ($plop->pcos_get_number($doc, "signaturefields[$i]/cades"))
        {
            print(", CAdES");
        }

        printf("\n");
    }
    if ($count > 0)
    {
        printf("No. of revisions: %d\n\n",
                $plop->pcos_get_number($doc, "revisions"));
    }

    printf("  Reader-enabled: %s\n", $plop->pcos_get_string($doc, "usagerights"));

    printf("    No. of pages: %d\n",
	$plop->pcos_get_number($doc, "length:pages"));

    printf("     Page 1 size: width=%g, height=%g\n",
	$plop->pcos_get_number($doc, "pages[0]/width"),
	$plop->pcos_get_number($doc, "pages[0]/height"));

    $count = $plop->pcos_get_number($doc, "length:fonts");
    printf("    No. of fonts: %d\n", $count);

    for ($i=0; $i < $count; $i++) {
	if ($plop->pcos_get_number($doc, "fonts[$i]/embedded")) {
	    printf("embedded ");
	}
	else {
	    printf("unembedded ");
	}

	printf("%s font ",
	    $plop->pcos_get_string($doc, "fonts[$i]/type"));
	printf("%s\n",
	    $plop->pcos_get_string($doc, "fonts[$i]/name"));
    }

    printf("\n");

    $plainmetadata =
	$plop->pcos_get_number($doc, "encrypt/plainmetadata");

    if ($pcosmode == 1 && !$plainmetadata &&
	( $plop->pcos_get_number($doc, "encrypt/nocopy"))) {
	die("Restricted mode: no more information available\n\n");
    }

    # --------- document info keys and XMP metadata (requires master pw
    # or plaintext metadata)
    #

    $count = $plop->pcos_get_number($doc, "length:/Info");

    for ($i=0; $i < $count; $i++) {
	$objtype = $plop->pcos_get_string($doc, "type:/Info[$i]");
	printf("%16s: ", $plop->pcos_get_string($doc, "/Info[$i].key"));

	# Info entries can be stored as string or name objects
	if ($objtype == "string" || $objtype == "name")
	{
	    printf("'%10s'\n",
		    $plop->pcos_get_string($doc, "/Info[$i]"));
	}
	else
	{
	    printf("(%s object)\n",
		$plop->pcos_get_string($doc, "type:/Info[$i]"));
	}
    }

    printf("\n   XMP meta data: ");

    $objtype = $plop->pcos_get_string($doc, "type:/Root/Metadata");
    if ($objtype == "stream") {
	$contents = $plop->pcos_get_stream($doc, "", "/Root/Metadata");
	printf("%d bytes ", strlen($contents));

	# This demonstrates Unicode conversion 
	$contents = $plop->convert_to_unicode("utf8", $contents,
						"outputformat=utf16");
	printf("(%d Unicode characters)\n\n", strlen($contents)/2);
    }
    else {
	printf("not present\n\n");
    }

    $plop->close_document($doc, "");

    print("</pre>\n");
}
catch (PLOPException $e) {
    die("PLOP exception occurred in dumper sample:\n" .
        "[" . $e->get_errnum() . "] " . $e->get_apiname() . ": " .
        $e->get_errmsg() . "\n");
    }
catch (Exception $e) {
    die($e);
}

$plop = 0;

?>
